from matplotlib.axes import Axes
from .artist import SecStructArtist
from .artist_dssp import SecStructArtistDssp


def draw(secstruct: str or list, xpos=None, ypos: float = 0., ax: Axes = None,
            height=1., linewidth=1., zorder=10, helix_kwargs=None, loop_kwargs=None, 
            sheet_kwargs=None):
    """Draw a secondary structure scheme.
    
    Parameters:
    -----------
        secstruct : str or array[N]
            Residue-wise secondary structure lables to be drawn. Every label
            should be present in the self.artists dictionary.
        xpos : array[N]
            The positions of each residue in secstruct on the x-axis. This
            is assumed to be in strictly ascending order.
        ypos : float
            Position of the secondary structure scheme on the y-axis. `ypos`
            corresponds to the center of the secondary structure scheme.
        ax : from matplotlib.axes import Axes
            The subplot where the secondary structure scheme should be drawn
            into (e.g., generated by `matplotlib.pyplot.subplots`).

    Returns:
    --------
        drawn_elements : List[DrawnSecStructElement]
            A list of the elements drawn in the secondary structure scheme
    """
    artist = SecStructArtist(
        height=height, linewidth=linewidth, zorder=zorder, helix_kwargs=helix_kwargs, 
        loop_kwargs=loop_kwargs, sheet_kwargs=sheet_kwargs)
    
    return artist.draw(secstruct, xpos, ypos, ax=ax)